@@ -5,9 +5,10 @@ Integration (not unit) tests for pylast.py
 import re
 import time
 
-import pylast
 import pytest
 
+import pylast
+
 from .test_pylast import WRITE_TEST, TestPyLastWithLastFm
 
 
@@ -26,7 +27,7 @@ class TestPyLastNetwork(TestPyLastWithLastFm):
 
         # Assert
         # limit=2 to ignore now-playing:
-        last_scrobble = lastfm_user.get_recent_tracks(limit=2)[0]
+        last_scrobble = list(lastfm_user.get_recent_tracks(limit=2))[0]
         assert str(last_scrobble.track.artist).lower() == artist
         assert str(last_scrobble.track.title).lower() == title
 
@@ -63,7 +64,7 @@ class TestPyLastNetwork(TestPyLastWithLastFm):
         self.network.enable_rate_limit()
         then = time.time()
         # Make some network call, limit not applied first time
-        self.network.get_user(self.username)
+        self.network.get_top_artists()
         # Make a second network call, limiting should be applied
         self.network.get_top_artists()
         now = time.time()
