@@ -4,12 +4,13 @@ Integration (not unit) tests for pylast.py
 """
 import calendar
 import datetime as dt
+import inspect
 import os
 import re
-import warnings
+
+import pytest
 
 import pylast
-import pytest
 
 from .test_pylast import TestPyLastWithLastFm
 
@@ -68,7 +69,7 @@ class TestPyLastUser(TestPyLastWithLastFm):
         if int(registered):
             # Last.fm API broken? Used to be yyyy-mm-dd not Unix timestamp
             assert registered == "1037793040"
-        else:
+        else:  # pragma: no cover
             # Old way
             # Just check date because of timezones
             assert "2002-11-20 " in registered
@@ -192,8 +193,13 @@ class TestPyLastUser(TestPyLastWithLastFm):
 
         # Act/Assert
         self.helper_validate_cacheable(lastfm_user, "get_friends")
-        self.helper_validate_cacheable(lastfm_user, "get_loved_tracks")
-        self.helper_validate_cacheable(lastfm_user, "get_recent_tracks")
+        # no cover whilst xfail:
+        self.helper_validate_cacheable(  # pragma: no cover
+            lastfm_user, "get_loved_tracks"
+        )
+        self.helper_validate_cacheable(  # pragma: no cover
+            lastfm_user, "get_recent_tracks"
+        )
 
     def test_user_get_top_tags_with_limit(self):
         # Arrange
@@ -387,6 +393,23 @@ class TestPyLastUser(TestPyLastWithLastFm):
         assert str(tracks[0].track.artist) == "Seun Kuti & Egypt 80"
         assert str(tracks[0].track.title) == "Struggles Sounds"
 
+    def test_get_recent_tracks_is_streamable(self):
+        # Arrange
+        lastfm_user = self.network.get_user("bbc6music")
+        start = dt.datetime(2020, 2, 15, 15, 00)
+        end = dt.datetime(2020, 2, 15, 15, 40)
+
+        utc_start = calendar.timegm(start.utctimetuple())
+        utc_end = calendar.timegm(end.utctimetuple())
+
+        # Act
+        tracks = lastfm_user.get_recent_tracks(
+            time_from=utc_start, time_to=utc_end, limit=None, stream=True
+        )
+
+        # Assert
+        assert inspect.isgenerator(tracks)
+
     def test_get_playcount(self):
         # Arrange
         user = self.network.get_user("RJ")
@@ -464,20 +487,8 @@ class TestPyLastUser(TestPyLastWithLastFm):
 
         # Act
         result1 = user.get_track_scrobbles(artist, title, cacheable=False)
-        result2 = user.get_track_scrobbles(artist, title, cacheable=True)
-        result3 = user.get_track_scrobbles(artist, title)
+        result2 = list(user.get_track_scrobbles(artist, title, cacheable=True))
+        result3 = list(user.get_track_scrobbles(artist, title))
 
         # Assert
         self.helper_validate_results(result1, result2, result3)
-
-    def test_get_artist_tracks_deprecated(self):
-        # Arrange
-        lastfm_user = self.network.get_user(self.username)
-
-        # Act / Assert
-        with warnings.catch_warnings(), pytest.raises(
-            pylast.WSError,
-            match="Deprecated - This type of request is no longer supported",
-        ):
-            warnings.filterwarnings("ignore", category=DeprecationWarning)
-            lastfm_user.get_artist_tracks(artist="Test Artist")
